==> sinosun-ui-0.3.1.tgz: package/es/index.js <==
var ENV = process.env.NODE_ENV;
if (ENV !== 'production' && ENV !== 'test' && typeof console !== 'undefined' && console.warn && typeof window !== 'undefined') {
    console.warn('You are using a whole package of sinosun-ui, ' + 'please use https://yqtdev.sinosun.com:18094/static/docs/component/index.html#/./foreword to reduce app bundle size.');
}

/* 通用 */
import SnButton from './button';
import SnIcon from './icon';

/* 布局 */
import SnFlexBox from './flex-box';
import SnFlexItem from './flex-item';
import SnWingBlank from './wing-blank';
import SnWhiteSpace from './white-space';

/* 导航 */
import SnTabs from './tabs';
import SnTab from './tab';

/* 数据录入 */
import SnInput from './input';
import SnInputItem from './input-item';
import SnTextarea from './textarea';
import SnTextareaItem from './textarea-item';
import SnInputNumber from './input-number';
import SnInputNumberItem from './input-number-item';
import SnNumberKeyboard from './number-keyboard';
import SnDatetimePickerView from './datetime-picker-view';
import SnDatetimePicker from './datetime-picker';
import SnRangePickerView from './range-picker-view';
import SnRangePicker from './range-picker';
import SnRadio from './radio';
import SnRadioGroup from './radio-group';
import SnRadioItem from './radio-item';
import SnCheckbox from './checkbox';
import SnCheckboxGroup from './checkbox-group';
import SnCheckboxItem from './checkbox-item';
import SnStepper from './stepper';
import SnPickerView from './picker-view';
import SnPicker from './picker';
import SnSwitch from './switch';
import SnUpload from './upload';
import SnMstpUpload from './mstp-upload';

/* 数据展示 */
import SnList from './list';
import SnListItem from './list-item';
import SnEmpty from './empty';
import SnDropdownMenu from './dropdown-menu';
import SnDropdownMenuItem from './dropdown-menu-item';
import SnPopup from './popup';
import SnModal from './modal';
import SnCollapse from './collapse';
import SnCollapsePanel from './collapse-panel';
import SnCarousel from './carousel';
import SnCarouselItem from './carousel-item';

/* 反馈 */
import SnLoading from './loading';
import SnToast from './toast';
import SnOverlay from './overlay';

/* 手势 */
import SnSwipeAction from './swipe-action';

/* 组合 */

/* 其他 */
import TransferDom from './directives/transfer-dom';

var components = [SnButton, SnIcon, SnFlexBox, SnFlexItem, SnWingBlank, SnWhiteSpace, SnTabs, SnTab, SnInput, SnInputItem, SnTextarea, SnTextareaItem, SnDatetimePickerView, SnDatetimePicker, SnRangePickerView, SnRangePicker, SnRadio, SnRadioGroup, SnRadioItem, SnInputNumber, SnInputNumberItem, SnNumberKeyboard, SnCheckbox, SnCheckboxGroup, SnCheckboxItem, SnStepper, SnPickerView, SnPicker, SnSwitch, SnUpload, SnMstpUpload, SnList, SnListItem, SnEmpty, SnDropdownMenu, SnDropdownMenuItem, SnModal, SnCollapse, SnCollapsePanel, SnPopup, SnCarousel, SnCarouselItem, SnLoading, SnToast, SnOverlay, SnSwipeAction];

var install = function install(Vue) {
    components.map(function (component) {
        Vue.use(component);
    });
};

/* istanbul ignore if */
if (typeof window !== 'undefined' && window.Vue) {
    install(window.Vue);
}

export { SnButton, SnIcon, SnFlexBox, SnFlexItem, SnWingBlank, SnWhiteSpace, SnTabs, SnTab, SnInput, SnInputItem, SnTextarea, SnTextareaItem, SnDatetimePickerView, SnDatetimePicker, SnRangePickerView, SnRangePicker, SnRadio, SnRadioGroup, SnRadioItem, SnInputNumber, SnInputNumberItem, SnNumberKeyboard, SnCheckbox, SnCheckboxGroup, SnCheckboxItem, SnStepper, SnPickerView, SnPicker, SnSwitch, SnUpload, SnMstpUpload, SnList, SnListItem, SnEmpty, SnDropdownMenu, SnDropdownMenuItem, SnModal, SnCollapse, SnCollapsePanel, SnPopup, SnCarousel, SnCarouselItem, SnLoading, SnToast, SnOverlay, SnSwipeAction, TransferDom };

export default {
    install: install
};

==> sinosun-ui-0.3.6.tgz: package/es/index.js <==
var ENV = process.env.NODE_ENV;
if (ENV !== 'production' && ENV !== 'test' && typeof console !== 'undefined' && console.warn && typeof window !== 'undefined') {
    console.warn('You are using a whole package of sinosun-ui, ' + 'please use https://yqtdev.sinosun.com:18094/static/docs/component/index.html#/./foreword to reduce app bundle size.');
}

/* 通用 */
import SnButton from './button';
import SnIcon from './icon';

/* 布局 */
import SnFlexBox from './flex-box';
import SnFlexItem from './flex-item';
import SnWingBlank from './wing-blank';
import SnWhiteSpace from './white-space';

/* 导航 */
import SnTabs from './tabs';
import SnTab from './tab';

/* 数据录入 */
import SnInput from './input';
import SnInputItem from './input-item';
import SnTextarea from './textarea';
import SnTextareaItem from './textarea-item';
import SnInputNumber from './input-number';
import SnInputNumberItem from './input-number-item';
import SnNumberKeyboard from './number-keyboard';
import SnSearch from './search';
import SnDatetimePickerView from './datetime-picker-view';
import SnDatetimePicker from './datetime-picker';
import SnRangePickerView from './range-picker-view';
import SnRangePicker from './range-picker';
import SnRadio from './radio';
import SnRadioGroup from './radio-group';
import SnRadioItem from './radio-item';
import SnCheckbox from './checkbox';
import SnCheckboxGroup from './checkbox-group';
import SnCheckboxItem from './checkbox-item';
import SnStepper from './stepper';
import SnPickerView from './picker-view';
import SnPicker from './picker';
import SnSwitch from './switch';
import SnUpload from './upload';
import SnMstpUpload from './mstp-upload';

/* 数据展示 */
import SnList from './list';
import SnListItem from './list-item';
import SnEmpty from './empty';
import SnDropdownMenu from './dropdown-menu';
import SnDropdownMenuItem from './dropdown-menu-item';
import SnPopup from './popup';
import SnModal from './modal';
import SnCollapse from './collapse';
import SnCollapsePanel from './collapse-panel';
import SnCarousel from './carousel';
import SnCarouselItem from './carousel-item';
import SnActionSheet from './action-sheet';

/* 反馈 */
import SnLoading from './loading';
import SnToast from './toast';
import SnOverlay from './overlay';

/* 手势 */
import SnPullToRefresh from './pull-to-refresh';
import SnSwipeAction from './swipe-action';

/* 组合 */

/* 其他 */
import TransferDom from './directives/transfer-dom';

var components = [SnButton, SnIcon, SnFlexBox, SnFlexItem, SnWingBlank, SnWhiteSpace, SnTabs, SnTab, SnInput, SnInputItem, SnTextarea, SnTextareaItem, SnDatetimePickerView, SnDatetimePicker, SnRangePickerView, SnRangePicker, SnRadio, SnRadioGroup, SnRadioItem, SnInputNumber, SnInputNumberItem, SnNumberKeyboard, SnSearch, SnCheckbox, SnCheckboxGroup, SnCheckboxItem, SnStepper, SnPickerView, SnPicker, SnSwitch, SnUpload, SnMstpUpload, SnList, SnListItem, SnEmpty, SnDropdownMenu, SnDropdownMenuItem, SnModal, SnCollapse, SnCollapsePanel, SnPopup, SnCarousel, SnCarouselItem, SnActionSheet, SnLoading, SnToast, SnOverlay, SnPullToRefresh, SnSwipeAction];

var install = function install(Vue) {
    components.map(function (component) {
        Vue.use(component);
    });
};

/* istanbul ignore if */
if (typeof window !== 'undefined' && window.Vue) {
    install(window.Vue);
}

export { SnButton, SnIcon, SnFlexBox, SnFlexItem, SnWingBlank, SnWhiteSpace, SnTabs, SnTab, SnInput, SnInputItem, SnTextarea, SnTextareaItem, SnDatetimePickerView, SnDatetimePicker, SnRangePickerView, SnRangePicker, SnRadio, SnRadioGroup, SnRadioItem, SnInputNumber, SnInputNumberItem, SnNumberKeyboard, SnSearch, SnCheckbox, SnCheckboxGroup, SnCheckboxItem, SnStepper, SnPickerView, SnPicker, SnSwitch, SnUpload, SnMstpUpload, SnList, SnListItem, SnEmpty, SnDropdownMenu, SnDropdownMenuItem, SnModal, SnCollapse, SnCollapsePanel, SnPopup, SnCarousel, SnCarouselItem, SnActionSheet, SnLoading, SnToast, SnOverlay, SnPullToRefresh, SnSwipeAction, TransferDom };

export default {
    install: install
};
